import Immutable from 'seamless-immutable';

import mount, { reducer, type } from './mount';


describe('mount', () => {

    it('should mount state if undefined', () => {
        const root = 'test';

        const action = mount({ initialComponentState: { my: 'state' }, root });
        const state = reducer[type](Immutable({ meta: { mounted: {} } }), action);

        expect(state).toEqual({ [root]: { my: 'state' }, meta: { mounted: { [root]: true } } });
    });

    it('should mount state if defined but not marked as mounted', () => {
        const root = 'test';

        const action = mount({ initialComponentState: { my: 'state' }, root });
        const state = reducer[type](Immutable({ [root]: { yada: 'yada, yada' }, meta: { mounted: {} } }), action);

        expect(state).toEqual({ [root]: { my: 'state' }, meta: { mounted: { [root]: true } } });
    });

    it('should not re-mount state', () => {
        const root = 'test';

        const action = mount({ initialComponentState: { my: 'state' }, root });
        const state = reducer[type](Immutable({ meta: { mounted: {} } }), action);

        const raction = mount({ initialComponentState: { my: 'new-state' }, root });
        const rstate = reducer[type](state, raction);

        expect(rstate).toEqual({ [root]: { my: 'state' }, meta: { mounted: { [root]: true } } });
    });

});
