import React from 'react';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Datepicker from './Datepicker';
import DatepickerContainer, { collapseType, expandType } from './DatepickerContainer';

import datepickerCollapse from './redux/datepickerCollapse';
import datepickerExpand from './redux/datepickerExpand';
import datepickerState from './redux/datepickerState';

import createStore from '../../test-utils/createStore';


const block = purebem.of('test-datepicker');
const controlElement = block('control');

const TestDatepicker = Datepicker({
    block,
    displayName: 'TestDatepicker'
});

const TestDatepickerContainer = DatepickerContainer({
    Component: TestDatepicker
});

describe('DatepickerContainer', () => {
    const path = 'picker';
    const root = 'test';
    const actionTypePrefix = 'TEST-DATEPICKER';

    it('should dispatch expand event when clicked and collapsed', () => {
        const store = createStore({
            test: {
                picker: datepickerState({
                    value: new Date(2000, 0, 1)
                })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestDatepickerContainer
                    actionTypePrefix={ actionTypePrefix }
                    customActionMetadata={ { index: 1 } }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const node = TestUtils.findRenderedDOMComponentWithClass(provider, controlElement);
        TestUtils.Simulate.click(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(datepickerExpand({
            custom: { index: 1 },
            path,
            root,
            type: expandType(actionTypePrefix)
        }));
    });

    it('should dispatch collapse event when clicked and expanded', () => {
        const store = createStore({
            test: {
                picker: datepickerState({
                    expanded: true,
                    value: new Date(2000, 0, 1)
                })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestDatepickerContainer
                    actionTypePrefix={ actionTypePrefix }
                    customActionMetadata={ { index: 1 } }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const node = TestUtils.findRenderedDOMComponentWithClass(provider, controlElement);
        TestUtils.Simulate.click(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(datepickerCollapse({
            currentMonth: +new Date(2000, 0, 1),
            custom: { index: 1 },
            path,
            root,
            selectedIndex: +new Date(2000, 0, 1),
            type: collapseType(actionTypePrefix)
        }));
    });

});
