import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';

import Monthpicker from './Monthpicker';
import monthpicker from './redux/monthpickerState';


const TestMonthpicker = Monthpicker({
    block: purebem.of('test-monthpicker'),
    displayName: 'TestMonthpicker'
});

describe('Monthpicker', () => {

    it('should render year, and month', () => {
        const wrapper = mount(
            <TestMonthpicker
                { ...monthpicker({ value: +new Date(2000, 0, 1) }) } />
        );

        expect(wrapper.text()).toBe('Month--1 2000');
    });

    it('should render year, and month range with negative offset', () => {
        const wrapper = mount(
            <TestMonthpicker
                yearOffset={ -1 }
                { ...monthpicker({ value: +new Date(2000, 0, 1) }) } />
        );

        expect(wrapper.text()).toBe('Month--1 1999 Month--1 2000');
    });

    it('should render year, and month range with offset', () => {
        const wrapper = mount(
            <TestMonthpicker
                yearOffset={ 1 }
                { ...monthpicker({ value: +new Date(2000, 0, 1) }) } />
        );

        expect(wrapper.text()).toBe('Month--1 2000 Month--1 2001');
    });

    it('should change value when clicking next', () => {
        const onChange = jest.fn();

        const wrapper = mount(
            <TestMonthpicker
                onChange={ onChange }
                { ...monthpicker({ value: +new Date(2000, 0, 1) }) } />
        );

        wrapper.find('MonthpickerNextMonth').simulate('click');
        expect(onChange).toHaveBeenCalledWith(+new Date(2000, 1, 1));
    });

    it('should change value when clicking previous', () => {
        const onChange = jest.fn();

        const wrapper = mount(
            <TestMonthpicker
                onChange={ onChange }
                { ...monthpicker({ value: +new Date(2000, 0, 1) }) } />
        );

        wrapper.find('MonthpickerPreviousMonth').simulate('click');
        expect(onChange).toHaveBeenCalledWith(+new Date(1999, 11, 1));
    });

});
