import React from 'react';
import purebem from 'purebem';
import { mount } from 'enzyme';
import { Provider } from 'react-redux';

import Monthpicker from './Monthpicker';
import MonthpickerContainer, { changeType } from './MonthpickerContainer';

import monthpickerChange from './redux/monthpickerChange';
import monthpickerState from './redux/monthpickerState';

import createStore from '../../test-utils/createStore';


const TestMonthpicker = Monthpicker({
    block: purebem.of('test-monthpicker'),
    displayName: 'TestMonthpicker'
});

const TestMonthpickerContainer = MonthpickerContainer({
    Component: TestMonthpicker
});

describe('MonthpickerContainer', () => {
    const path = 'picker';
    const root = 'test';
    const actionTypePrefix = 'TEST-MONTHPICKER';

    it('should dispatch change event when clicking next', () => {
        const store = createStore({
            test: {
                picker: monthpickerState({
                    value: +new Date(2000, 0, 1)
                })
            }
        });

        const wrapper = mount(
            <Provider store={ store }>
                <TestMonthpickerContainer
                    actionTypePrefix={ actionTypePrefix }
                    customActionMetadata={ { index: 1 } }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        wrapper.find('MonthpickerNextMonth').simulate('click');

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(monthpickerChange({
            custom: { index: 1 },
            path,
            root,
            type: changeType(actionTypePrefix),
            value: +new Date(2000, 1, 1)
        }));
    });


    it('should dispatch change event when clicking next', () => {
        const store = createStore({
            test: {
                picker: monthpickerState({
                    value: +new Date(2000, 0, 1)
                })
            }
        });

        const wrapper = mount(
            <Provider store={ store }>
                <TestMonthpickerContainer
                    actionTypePrefix={ actionTypePrefix }
                    customActionMetadata={ { index: 1 } }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        wrapper.find('MonthpickerPreviousMonth').simulate('click');

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(monthpickerChange({
            custom: { index: 1 },
            path,
            root,
            type: changeType(actionTypePrefix),
            value: +new Date(1999, 11, 1)
        }));
    });

});
