import React from 'react';
import ReactDOM from 'react-dom';
import TestUtils from 'react-addons-test-utils';
import purebem from 'purebem';
import { Provider } from 'react-redux';

import Textarea from './Textarea';
import TextareaContainer, { changeType } from './TextareaContainer';

import textareaChange from './redux/textareaChange';
import textareaState from './redux/textareaState';

import createStore from '../../test-utils/createStore';


const TestTextarea = Textarea({
    block: purebem.of('test-Textarea'),
    displayName: 'TestTextarea'
});

const TestTextareaContainer = TextareaContainer({
    Component: TestTextarea
});

describe('TextareaContainer', () => {
    const path = 'text';
    const root = 'test';
    const actionTypePrefix = 'TEST-TEXTAREA';

    it('should dispatch change event on change', () => {
        const store = createStore({
            test: {
                text: textareaState()
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestTextareaContainer
                    actionTypePrefix={ actionTypePrefix }
                    customActionMetadata={ { index: 1 } }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const container = TestUtils.findRenderedComponentWithType(provider, TestTextareaContainer);
        const node = ReactDOM.findDOMNode(container);
        node.value = 'a';

        TestUtils.Simulate.change(node);

        const actions = store.getState().actions;

        expect(actions.length).toBe(1);
        expect(actions[0]).toEqual(textareaChange({
            custom: { index: 1 },
            path,
            root,
            type: changeType(actionTypePrefix),
            rawValue: 'a',
            value: 'a'
        }));
    });

    it('should read value from store', () => {
        const store = createStore({
            test: {
                text: textareaState({ rawValue: 'a', value: 'a' })
            }
        });

        const provider = TestUtils.renderIntoDocument(
            <Provider store={ store }>
                <TestTextareaContainer
                    actionTypePrefix={ actionTypePrefix }
                    path={ path }
                    root={ root } />
            </Provider>
        );

        const container = TestUtils.findRenderedComponentWithType(provider, TestTextarea);
        const node = ReactDOM.findDOMNode(container);

        expect(node.value).toBe('a');
    });
});
